@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013-2018 Adam.Dybbroe
+# Copyright (c) 2013-2019 Adam.Dybbroe
 
 # Author(s):
 
@@ -20,7 +20,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Unit testing the 3.7 micron reflectance calculations"""
+"""Unit testing the 3.7 micron reflectance calculations."""
 
 from pyspectral.near_infrared_reflectance import Calculator
 import numpy as np
@@ -100,17 +100,10 @@ TEST_RSR_WN['20']['det-1']['response'] = RESP
 
 
 class TestReflectance(unittest.TestCase):
-
-    """Unit testing the reflectance calculations"""
-
-    def setUp(self):
-        """Set up"""
-        pass
+    """Unit testing the reflectance calculations."""
 
     def test_rsr_integral(self):
-        """Test calculating the integral of the relative spectral response
-        function. 
-        """
+        """Test calculating the integral of the relative spectral response function."""
         with patch('pyspectral.radiance_tb_conversion.RelativeSpectralResponse') as mymock:
             instance = mymock.return_value
             instance.rsr = TEST_RSR
@@ -135,20 +128,23 @@ class TestReflectance(unittest.TestCase):
         np.testing.assert_allclose(res / expected, 1.0, 6)
 
     def test_reflectance(self):
-        """Test the derivation of the reflective part of a 3.7 micron band"""
-
+        """Test the derivation of the reflective part of a 3.7 micron band."""
         with patch('pyspectral.radiance_tb_conversion.RelativeSpectralResponse') as mymock:
             instance = mymock.return_value
-            instance.rsr = TEST_RSR
+            # VIIRS doesn't have a channel '20' like MODIS so the generic
+            # mapping this test will end up using will find 'ch20' for VIIRS
+            viirs_rsr = {'ch20': TEST_RSR['20'], '99': TEST_RSR['99']}
+            instance.rsr = viirs_rsr
             instance.unit = '1e-6 m'
             instance.si_scale = 1e-6
 
             with self.assertRaises(NotImplementedError):
                 dummy = Calculator('Suomi-NPP', 'viirs', 10.8)
+                del dummy
 
             refl37 = Calculator('Suomi-NPP', 'viirs', 3.7)
             self.assertEqual(refl37.bandwavelength, 3.7)
-            self.assertEqual(refl37.bandname, '20')
+            self.assertEqual(refl37.bandname, 'ch20')
 
         with patch('pyspectral.radiance_tb_conversion.RelativeSpectralResponse') as mymock:
             instance = mymock.return_value
@@ -200,16 +196,3 @@ class TestReflectance(unittest.TestCase):
             self.assertTrue(hasattr(refl, 'compute'))
         except ImportError:
             pass
-
-    def tearDown(self):
-        """Clean up"""
-        pass
-
-
-def suite():
-    """The suite for test_reflectance."""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestReflectance))
-
-    return mysuite
